@@ -64,7 +64,7 @@ class Application(Gtk.Application):
         self._window = None
 
         self._coreselection = CoreSelection()
-        self._coremodel = CoreModel(self._coreselection)
+        self._coremodel = CoreModel(self)
 
         self._settings = Gio.Settings.new('org.gnome.Music')
         self._player = Player(self)
@@ -120,17 +120,28 @@ class Application(Gtk.Application):
         """
         return self._coreselection
 
+    @GObject.Property(type=Window, flags=GObject.ParamFlags.READABLE)
+    def window(self):
+        """Get main window.
+
+        :returns: Main window.
+        :rtype: Window
+        """
+        return self._window
+
     @log
     def _build_app_menu(self):
         action_entries = [
-            ('about', self._about),
-            ('help', self._help)
+            ('about', self._about, None),
+            ("help", self._help, ("app.help", ["F1"]))
         ]
 
-        for action, callback in action_entries:
+        for action, callback, accel in action_entries:
             simple_action = Gio.SimpleAction.new(action, None)
             simple_action.connect('activate', callback)
             self.add_action(simple_action)
+            if accel is not None:
+                self.set_accels_for_action(*accel)
 
     @log
     def _help(self, action, param):
